@@ -41,7 +41,7 @@ use Unicode::String;
 
 {    # BEGIN CLASS
 
-    use version; our $VERSION = qv('3.4.0.9');
+    use version; our $VERSION = qv('3.4.0.11');
     use re 'taint';    # Keep data captured by parens tainted
     delete @ENV{qw(PATH IFS CDPATH ENV BASH_ENV)};    # Make %ENV safe
 
@@ -403,7 +403,7 @@ use Unicode::String;
     # +======================================================================+
     # || lf                                                                 ||
     # +======================================================================+
-    # laudering LDAP filter
+    # laundering LDAP filter
     sub lf {
 
         # +------------------------------------------------------------------+
@@ -777,6 +777,30 @@ use Unicode::String;
 
     } ## end sub date_time
 
+    # +======================================================================+
+    # || date_epoch                                                          ||
+    # +======================================================================+
+    sub date_epoch {
+
+        # +------------------------------------------------------------------+
+        # | API
+
+        my ( $self, $arg_r ) = @_;
+        my $today = $arg_r->{today} || 0;
+
+        my $return = $EMPTY_STRING;
+
+        if ($today eq '1') {
+            $return = UnixDate( 'today', '%s' );
+        }elsif($today){
+            $return = UnixDate( ParseDate($today), '%s' );
+        }
+        # +------------------------------------------------------------------+
+        # | API
+        return $return;
+
+    } ## end sub date_epoch
+
     # +======================================================================+
     # || latin1_to_utf8                                                     ||
     # +======================================================================+
@@ -1285,7 +1309,7 @@ use Unicode::String;
 
             #|  cache_dir  |cfgbase|name
             #/var/cache/cipux/cipux/3c9f65e4f1c5d05638f63da289e78eb3
-            my $fn = "$eval_dir/$ndigest{$f}"; 
+            my $fn = "$eval_dir/$ndigest{$f}";
             $l->debug("evaluate md5 file [$fn]");
 
             if ( -e $fn ) {
@@ -1327,7 +1351,7 @@ CipUX - Common CipUX functions
 
 =head1 VERSION
 
-version 3.4.0.9
+version 3.4.0.11
 
 =head1 SYNOPSIS
 
